pub fn resolve_output_mode(cli_flag: Option<OutputMode>) -> OutputModeExpand description
Resolve the active output mode from a parsed Cli plus the
SUBX_OUTPUT environment variable.
--output always wins over the environment fallback.
pub fn resolve_output_mode(cli_flag: Option<OutputMode>) -> OutputModeResolve the active output mode from a parsed Cli plus the
SUBX_OUTPUT environment variable.
--output always wins over the environment fallback.