pub async fn execute(args: CacheArgs) -> Result<()>Expand description
Dispatch the cache subcommand using the production configuration service.
For testable code paths, prefer execute_with_config which accepts an
injected ConfigService.
pub async fn execute(args: CacheArgs) -> Result<()>Dispatch the cache subcommand using the production configuration service.
For testable code paths, prefer execute_with_config which accepts an
injected ConfigService.