pub struct MatchOpItem {
pub kind: &'static str,
pub source: String,
pub target: String,
pub applied: bool,
pub status: &'static str,
pub error: Option<MatchItemError>,
}Expand description
Planned (and possibly executed) match operation emitted in data.operations.
Fields
kind: &'static strOne of "rename", "copy", or "move".
source: StringSource path before the operation.
target: StringResolved destination path after the operation would be applied.
applied: booltrue only when the operation was actually applied to the filesystem.
status: &'static str"ok" or "error".
error: Option<MatchItemError>Populated only when status == "error".