apply_cached_operations

Function apply_cached_operations 

pub async fn apply_cached_operations(
    cache: &CacheData,
    config: &MatchConfig,
) -> Result<(), SubXError>
Replay a frozen cache plan reporting through a no-op sink.

Convenience wrapper over apply_cached_operations_with_reporter for callers with no reporting sink to attach.